Crate ruda_core

Crate ruda_core 

Ruda Common Library

This library contains common types used by other crates that must be shared.

Re-exports

pub use numeric::*;

Modules

arena
A circular, allocation-free arena for reusable memory blocks.
backtrace
Backtrace module to build error reports.
benchmark
Module for benchmark timings
config
Runtime configuration trait shared across crates.
device
Device module.
device_handle
Device handle module.
format
Format utilities.
future
Future utils with a compatible API for native, non-std and wasm environments.
numeric
Custom float implementations
profile
Module for profiling any executable part
quant
Quantization primitives required outside of ruda-kernel
rand
Rand module contains types for random number generation for non-std environments and for std environments.
reader
Useful when you need to read async data without having to decorate each function with async notation.
stream_id
Stream id related utilities.
stub
Stub module contains types for stubs for non-std environments and for std environments.